@@ -3,6 +3,10 @@ rainfall_bedoya2017 <- function(wave, Tmean=1e-6, Tsnr=3.5) {
   a <- subset(p, p[,1] > 0.6 & p[,1] < 1.2)
   mean_a <- mean(a[,2])
   std_a <- stats::sd(a[,2])
+  if (nrow(a) == 1) {
+    message("Not enough data to create standard deviation")
+    return(NULL)
+  }
   c <- mean_a/std_a
   if (mean_a > Tmean && c >Tsnr) {
     r <- mean_a
@@ -10,4 +14,4 @@ rainfall_bedoya2017 <- function(wave, Tmean=1e-6, Tsnr=3.5) {
     r <- 0
   }
   return(c(r))
-}
\ No newline at end of file
+}
